==> lxqt-panel_1.1.0.orig.tar.xz: lxqt-panel-1.1.0/plugin-customcommand/translations/customcommand_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LXQtCustomCommand</name>
    <message>
        <location filename="../lxqtcustomcommand.cpp" line="176"/>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Konfiguracja własnej komendy</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Wyświetlanie</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
        <source>Use icon from theme or browse file</source>
        <translation>Użyj ikony z motywu lub przeglądaj pliki</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Uruchom przez „bash -c”</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="45"/>
        <source>Select Font</source>
        <translation>Wybierz czcionkę</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="55"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="65"/>
        <source>Command</source>
        <translation>Komenda</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="75"/>
        <source>Font</source>
        <translation>Czcionka</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="82"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="101"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="104"/>
        <source>Use %1 to display command output</source>
        <translation>Użyj % 1, aby wyświetlić wynik polecenia</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="111"/>
        <source>Icon</source>
        <translation>Ikona</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="121"/>
        <source>Browse</source>
        <translation>Przeglądaj</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="131"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Automatyczne obracanie, gdy panel jest ustawiony w pionie</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="150"/>
        <source>echo Configure...</source>
        <translation>echo Konfiguruj...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="153"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="271"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="285"/>
        <source>Command to run</source>
        <translation>Komenda do uruchomienia</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="160"/>
        <source>Max Width</source>
        <translation>Maks. szerokość</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="212"/>
        <source>Repeat command after:</source>
        <translation>Powtórz komendę po:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
        <source> second(s)</source>
        <translation> sek</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="255"/>
        <source>Mouse Commands</source>
        <translation>Komendy myszy</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="261"/>
        <source>Click</source>
        <translation>Klik</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
        <source>Wheel Up</source>
        <translation>Kółko w górę</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="302"/>
        <source>Wheel Down</source>
        <translation>Kółko w dół</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="139"/>
        <source>Select Icon File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="139"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> lxqt-panel_1.2.1.orig.tar.xz: lxqt-panel-1.2.1/plugin-customcommand/translations/customcommand_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>LXQtCustomCommand</name>
    <message>
        <location filename="../lxqtcustomcommand.cpp" line="176"/>
        <source>Error</source>
        <translation>Błąd</translation>
    </message>
</context>
<context>
    <name>LXQtCustomCommandConfiguration</name>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="14"/>
        <source>Custom Command Configuration</source>
        <translation>Konfiguracja własnej komendy</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="20"/>
        <source>Display</source>
        <translation>Wyświetlanie</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="28"/>
        <source>Use icon from theme or browse file</source>
        <translation>Użyj ikony z motywu lub przeglądaj pliki</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="35"/>
        <source>Run with &quot;bash -c&quot;</source>
        <translation>Uruchom przez „bash -c”</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="45"/>
        <source>Select Font</source>
        <translation>Wybierz czcionkę</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="55"/>
        <source>Text</source>
        <translation>Tekst</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="65"/>
        <source>Command</source>
        <translation>Komenda</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="75"/>
        <source>Font</source>
        <translation>Czcionka</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="82"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="101"/>
        <source>%1</source>
        <translation>%1</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="104"/>
        <source>Use %1 to display command output</source>
        <translation>Użyj % 1, aby wyświetlić wynik polecenia</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="111"/>
        <source>Icon</source>
        <translation>Ikona</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="121"/>
        <source>Browse</source>
        <translation>Przeglądaj</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="131"/>
        <source>Autorotate when the panel is vertical</source>
        <translation>Automatyczne obracanie, gdy panel jest ustawiony w pionie</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="150"/>
        <source>echo Configure...</source>
        <translation>echo Konfiguruj...</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="153"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="271"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="278"/>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="285"/>
        <source>Command to run</source>
        <translation>Komenda do uruchomienia</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="160"/>
        <source>Max Width</source>
        <translation>Maks. szerokość</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="212"/>
        <source>Repeat command after:</source>
        <translation>Powtórz komendę po:</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="228"/>
        <source> second(s)</source>
        <translation> sek</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="255"/>
        <source>Mouse Commands</source>
        <translation>Komendy myszy</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="261"/>
        <source>Click</source>
        <translation>Klik</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="292"/>
        <source>Wheel Up</source>
        <translation>Kółko w górę</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.ui" line="302"/>
        <source>Wheel Down</source>
        <translation>Kółko w dół</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="139"/>
        <source>Select Icon File</source>
        <translation>Wybierz plik ikony</translation>
    </message>
    <message>
        <location filename="../lxqtcustomcommandconfiguration.cpp" line="139"/>
        <source>Images (*.png *.svg *.xpm *.jpg)</source>
        <translation>Obrazy (*.png *.svg *.xpm *.jpg)</translation>
    </message>
</context>
</TS>
